# unitorch.cli.models.bloom

## BloomProcessor

!!! tip
    **`core/process/bloom`** is the section for configuration of BloomProcessor.

::: unitorch.cli.models.bloom.BloomProcessor

## BloomForClassification

!!! tip
    **`core/model/classification/bloom`** is the section for configuration of BloomForClassification.

::: unitorch.cli.models.bloom.BloomForClassification

## BloomForPretrain

!!! tip
    **`core/model/pretrain/bloom`** is the section for configuration of BloomForPretrain.

::: unitorch.cli.models.bloom.BloomForPretrain

## BloomForGeneration

!!! tip
    **`core/model/generation/bloom`** is the section for configuration of BloomForGeneration.

::: unitorch.cli.models.bloom.BloomForGeneration
